@@ -1,14 +1,14 @@
 /** @file
 	Parser: string class decl.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_STRING_H
 #define PA_STRING_H
 
-static const char * const IDENT_STRING_H="$Date: 2008-07-21 07:37:02 $";
+static const char * const IDENT_STRING_H="$Date: 2009-11-09 00:37:44 $";
 
 // includes
 #include "pa_types.h"
@@ -17,10 +17,22 @@ static const char * const IDENT_STRING_H="$Date: 2008-07-21 07:37:02 $";
 extern "C" { // cord's author forgot to do that
 #define CORD_NO_IO
 #include "cord.h"
+
+#ifdef CORD_CAT_OPTIMIZATION
+#define CORD_cat(x, y) CORD_cat_optimized(x, y)
+#define CORD_cat_char_star(x, y, leny) CORD_cat_char_star_optimized(x, y, leny)
+#endif
 };
 
 // defines
 
+// cache hash code in String::Body for faster hash access
+#define HASH_CODE_CACHING
+
+// cache String::Body.length() for char* strings only, CORDs have own length
+#define STRING_LENGTH_CACHING
+
+
 // cord extension
 /* Returns true if x does contain                                       */
 /* char not_c at positions i..i+n. Value i,i+n must be < CORD_len(x).	*/
@@ -36,6 +48,7 @@ class Dictionary;
 class Request_charsets;
 class String;
 typedef Array<const String*> ArrayString;
+class VRegex;
 
 // generally useful
 
@@ -45,11 +58,6 @@ double pa_atod(const char* str, const String* problem_source=0);
 /// this is result of pos functions which mean that substr were not found
 #define STRING_NOT_FOUND ((size_t)-1)
 
-template<typename T>
-inline size_t get_length(T current) {
-	return current;
-}
-
 /** 
 	String which knows the lang of all it's langs.
 
@@ -57,6 +65,8 @@ inline size_t get_length(T current) {
 	- whether they are tainted or not, 
 	  and the lang which should be used to detaint them
 */
+
+
 class String: public PA_Object {
 public:
 
@@ -90,13 +100,15 @@ public:
 		L_FILE_SPEC='F',	///< file specification
 		L_HTTP_HEADER='h',	///< text in HTTP response header
 		L_MAIL_HEADER='m',	///< text in mail header
-		L_URI='U',		///< text in uri
-		L_SQL='Q',		///< ^table:sql body
-		L_JS='J',		///< JavaScript code
-		L_XML='X',		///< ^dom:set xml
-		L_HTML='H',		///< HTML code
-		L_REGEX='R',	///< RegEx expression
+		L_URI='U',			///< text in uri
+		L_SQL='Q',			///< ^table:sql body
+		L_JS='J',			///< JavaScript code
+		L_XML='X',			///< ^dom:set xml
+		L_HTML='H',			///< HTML code
+		L_REGEX='R',		///< RegEx expression
 		L_HTTP_COOKIE='C',	///< cookies encoded as %uXXXX for compartibility with js functions encode/decode
+		L_FILE_POST='f',	///< temporary escaping zero-char
+		L_PARSER_CODE='p',	///< ^process body
 		// READ WARNING ABOVE BEFORE ADDING ANYTHING
 		L_OPTIMIZE_BIT = 0x80  ///< flag, requiring cstr whitespace optimization
 	};
@@ -107,14 +119,16 @@ public:
 		TRIM_END
 	};
 
+	class Body;
+
 	union Languages {
 
 		struct {
 #ifdef PA_LITTLE_ENDIAN
 			Language lang:8;
-			int is_not_just_lang:sizeof(CORD)*8-8;
+			size_t is_not_just_lang:sizeof(CORD)*8-8;
 #elif defined(PA_BIG_ENDIAN)
-			int is_not_just_lang:sizeof(CORD)*8-8;
+			size_t is_not_just_lang:sizeof(CORD)*8-8;
 			Language lang:8;
 #else
 #	error word endianness not determined for some obscure reason
@@ -122,33 +136,35 @@ public:
 		} opt;
 		CORD langs;
 
-		template<typename C>
-		CORD make_langs(C current) const {
-			return opt.is_not_just_lang?
-				langs
-				:CORD_chars((char)opt.lang, get_length(current));
+		CORD make_langs(const Body& current) const {
+			return opt.is_not_just_lang?langs:CORD_chars((char)opt.lang, current.length());
 		}
 
 		CORD make_langs(size_t aoffset, size_t alength)  const {
 			return opt.is_not_just_lang?
-				CORD_substr(langs, aoffset, alength)
+				CORD_substr(langs, aoffset, alength, 0)
 				:CORD_chars((char)opt.lang, alength);
 		}
 
 		/// appending when 'langs' already contain something [simple cases handled elsewhere]
-		template<typename C>
-		void append(C current, 
-			const CORD to_nonempty_target_langs) {
+		void append(size_t current, const CORD to_nonempty_target_langs) {
 			assert(langs);
-
 			if(opt.is_not_just_lang)
 				langs=CORD_cat(langs, to_nonempty_target_langs);
-			else { // we were "just lang"
-				size_t current_size=get_length(current);
+			else {
+				assert(current);
+				langs=CORD_cat(CORD_chars((char)opt.lang, current), to_nonempty_target_langs);
+			}
+		}
+
+		void append(const Body& current, const CORD to_nonempty_target_langs) {
+			assert(langs);
+			if(opt.is_not_just_lang)
+				langs=CORD_cat(langs, to_nonempty_target_langs);
+			else {
+				size_t current_size=current.length();
 				assert(current_size);
-				langs=CORD_cat(
-					CORD_chars((char)opt.lang, current_size),  // first piece [making from just 'lang']
-					to_nonempty_target_langs); // new piece
+				langs=CORD_cat(CORD_chars((char)opt.lang, current_size), to_nonempty_target_langs);
 			}
 		}
 
@@ -164,46 +180,74 @@ public:
 		}
 
 		/// MUST be called exactly prior to modification of current [uses it's length]
-		template<typename C>
-		void append(C current, Language alang, size_t asize) {
+		void append(size_t current, Language alang, size_t length) {
 			assert(alang);
-			assert(asize);
+			assert(length);
 
 			if(!opt.is_not_just_lang)
 				if(opt.lang) {
-					if(opt.lang==alang) // same length? ignoring
+					if(opt.lang==alang) // same language? ignoring
 						return;
 				} else {
 					opt.lang=alang; // to uninitialized
 					return;
 				}
 
-			append(current, CORD_chars((char)alang, asize));
+			append(current, CORD_chars((char)alang, length));
 		}
 
-		/// MUST be called exactly prior to modification of current [uses it's length]
-		template<typename C>
-		void append(C current, size_t appending_length, 
-			const Languages src) {
-			assert(appending_length);
+		void append(const Body &current, Language alang, size_t length) {
+			assert(alang);
+			assert(length);
 
-			if(!langs)
+			if(!opt.is_not_just_lang)
+				if(opt.lang) {
+					if(opt.lang==alang) // same language? ignoring
+						return;
+				} else {
+					opt.lang=alang; // to uninitialized
+					return;
+				}
+
+			append(current, CORD_chars((char)alang, length));
+		}
+
+		void appendHelper(const Body& current, Language alang, const Body &length_helper) {
+			assert(alang);
+
+			if(!opt.is_not_just_lang)
+				if(opt.lang) {
+					if(opt.lang==alang) // same language? ignoring
+						return;
+				} else {
+					opt.lang=alang; // to uninitialized
+					return;
+				}
+
+			append(current, CORD_chars((char)alang, length_helper.length()));
+		}
+
+		void appendHelper(const Body& current, const Languages &src, const Body& length_helper) {
+			if(!langs){
 				langs=src.langs; // to uninitialized
+#ifdef CORD_CAT_OPTIMIZATION
+				if(opt.is_not_just_lang && !CORD_IS_STRING(langs))
+					CORD_concatenation_protect(langs);
+#endif
+			}
 			else if(!src.opt.is_not_just_lang)
-				append(current, src.opt.lang, appending_length); // simplifying when simple source
+				appendHelper(current, src.opt.lang, length_helper); // simplifying when simple source
 			else
-				append(current, src.make_langs(appending_length));
+				append(current, src.make_langs(length_helper));
 		}
-		
+
 		/// MUST be called exactly prior to modification of current [uses it's length]
-		template<typename C>
-		void append(C current,
-			const Languages src, size_t aoffset, size_t alength) {
+		void append(const Body& current, const Languages src, size_t aoffset, size_t alength) {
 			assert(alength);
 
 			if(!langs) // to uninitialized?
 				if(src.opt.is_not_just_lang)
-					langs=CORD_substr(src.langs, aoffset, alength); // to uninitialized complex
+					langs=CORD_substr(src.langs, aoffset, alength, 0); // to uninitialized complex
 				else
 					opt.lang=src.opt.lang; // to uninitialized simple
 			else 
@@ -234,14 +278,20 @@ public:
 					: 0;
 		};
 
-		template<typename C, typename I> 
-		void for_each(C current, 
-			int callback(char, size_t, I), I info) const {
-			
+		template<typename I> 
+		void for_each(size_t current, int callback(char, size_t, I), I info) const {
 			if(opt.is_not_just_lang)
 				CORD_block_iter(langs, 0, (CORD_block_iter_fn)callback, info);
 			else
-				callback(opt.lang, get_length(current), info);
+				callback(opt.lang, current, info);
+		}
+
+		template<typename I> 
+		void for_each(const Body& current, int callback(char, size_t, I), I info) const {
+			if(opt.is_not_just_lang)
+				CORD_block_iter(langs, 0, (CORD_block_iter_fn)callback, info);
+			else
+				callback(opt.lang, current.length(), info);
 		}
 
 		bool invariant(size_t current_length) const {
@@ -257,49 +307,102 @@ public:
 
 		CORD body;
 
+#ifdef HASH_CODE_CACHING
+		// cached hash code is not reseted on write operations as test shows 
+		// that string body does not change after it is stored as a hash key
+		mutable uint hash_code;
+#endif
+
+#ifdef STRING_LENGTH_CACHING
+		// cached length is reseted on modification, used only for char*, not CORD
+		mutable size_t string_length;
+#define INIT_LENGTH ,string_length(0)
+#define ZERO_LENGTH string_length=0;
+#else
+#define INIT_LENGTH
+#define ZERO_LENGTH
+#endif
+
 	public:
 
 		const char* v() const;
 		void dump() const;
 
-		Body(): body(CORD_EMPTY) {}
-		Body(CORD abody): body(abody) {
+#ifdef HASH_CODE_CACHING
+		Body(): body(CORD_EMPTY), hash_code(0) INIT_LENGTH {}
+		Body(CORD abody, uint ahash_code): body(abody), hash_code(ahash_code) INIT_LENGTH {}
+		Body(CORD abody): body(abody), hash_code(0) INIT_LENGTH {
+#else
+		Body(): body(CORD_EMPTY) INIT_LENGTH {}
+		Body(CORD abody): body(abody) INIT_LENGTH {
+#endif
+#ifdef CORD_CAT_OPTIMIZATION
+			assert(!body // no body
+				|| *body // ordinary string
+				|| body[1]==1 // CONCAT_HDR
+				|| body[1]==3 // CONCAT_HDR_READ_ONLY
+				|| body[1]==4 // FN_HDR 
+				|| body[1]==6 // SUBSTR_HDR 
+				);
+#else
 			assert(!body // no body
 				|| *body // ordinary string
 				|| body[1]==1 // CONCAT_HDR
 				|| body[1]==4 // FN_HDR 
 				|| body[1]==6 // SUBSTR_HDR 
 				);
+#endif
 		}
-		/// WARNING: length is only HELPER length, str in ANY case should be zero-terminated
-		Body(const char* str, size_t helper_length): body(CORD_EMPTY) {
-			append_know_length(str, helper_length?helper_length:strlen(str));
-		}
+
 		static Body Format(int value);
 
-		void clear() { body=CORD_EMPTY; }
+		void clear() { ZERO_LENGTH body=CORD_EMPTY; }
 
 		bool operator! () const { return is_empty(); }
 
-		uint hash_code() const;
+		CORD get_cord() const { return body; }
+		uint get_hash_code() const;
 
-		const char* cstr() const { return CORD_to_const_char_star(body); }
-		char* cstrm() const { return CORD_to_char_star(body); }
+		const char* cstr() const {
+#ifdef STRING_LENGTH_CACHING
+			string_length = length();
+			if(string_length)
+				return const_cast<Body*>(this)->body=CORD_to_const_char_star(body, string_length);
+#endif
+			return CORD_to_const_char_star(body, length());
+		}
 
+		char* cstrm() const { return CORD_to_char_star(body, length()); }
+
+#ifdef STRING_LENGTH_CACHING
+		void set_length(size_t alength){ string_length = alength; }
+		size_t length() const { return body ? CORD_IS_STRING(body) ? string_length ? string_length : (string_length=strlen(body)) : CORD_len(body) : 0; }
+#else
 		size_t length() const { return CORD_len(body); }
+#endif
 
 		bool is_empty() const { return body==CORD_EMPTY; }
 
 		void append_know_length(const char *str, size_t known_length) {
-			if(known_length)
-				body=CORD_cat_char_star(body, str, known_length);
+			if(known_length){
+				if(body){
+					body = CORD_cat_char_star(body, str, known_length);
+					ZERO_LENGTH 
+				} else {
+					body=str;
+#ifdef STRING_LENGTH_CACHING
+					string_length=known_length;
+#endif
+				}
+			}
 		}
 		void append_strdup_know_length(const char* str, size_t known_length) {
 			if(known_length)
 				append_know_length(pa_strdup(str, known_length), known_length);
 		}
-		void append(char c) { body=CORD_cat_char(body, c); }
-		Body& operator << (const Body src) { body=CORD_cat(body, src.body); return *this; }
+		void append(char c) { ZERO_LENGTH body=CORD_cat_char(body, c); }
+		Body& operator << (const Body src) { ZERO_LENGTH body=CORD_cat(body, src.body); return *this; }
+
 		Body& operator << (const char* str) { append_know_length(str, strlen(str)); return *this; }
 
 		// could not figure out why this operator is needed [should do this chain: string->simple->==]
@@ -315,14 +418,14 @@ public:
 		}
 
 		char fetch(size_t index) const { return CORD_fetch(body, index); }
-		Body mid(size_t index, size_t length) const { return CORD_substr(body, index, length); }
-		size_t pos(const char* substr, size_t offset=0) const { return CORD_str(body, offset, substr); }
+		Body mid(size_t aindex, size_t alength) const { return CORD_substr(body, aindex, alength, length()); }
+		size_t pos(const char* substr, size_t offset=0) const { return CORD_str(body, offset, substr, length()); }
 		size_t pos(const Body substr, size_t offset=0) const { 
-			if(!substr.length())
+			if(substr.is_empty())
 				return STRING_NOT_FOUND; // in this case CORD_str returns 0 [parser users got used to -1]
 
 			// CORD_str checks for bad offset [CORD_chr does not]
-			return CORD_str(body, offset, substr.body); 
+			return CORD_str(body, offset, substr.body, length()); 
 		}
 		size_t pos(char c, 
 			size_t offset=0) const {
@@ -332,16 +435,13 @@ public:
 			return CORD_chr(body, offset, c);
 		}
 
-		template<typename I> int for_each(
-			int (*f)(char c, I), 
-			I info) const {
+		template<typename I>
+		int for_each(int (*f)(char c, I), I info) const {
 			return CORD_iter(body, (CORD_iter_fn)f, (void*)info);
 		}
 
-		template<typename I> int for_each(
-			int (*f1)(char c, I), 
-			int (*f2)(const char* s, I), 
-			I info) const {
+		template<typename I>
+		int for_each(int (*f1)(char c, I), int (*f2)(const char* s, I), I info) const {
 			return CORD_iter5(body, 0, (CORD_iter_fn)f1, (CORD_batched_iter_fn)f2, info);
 		}
 
@@ -353,7 +453,7 @@ public:
 
 		/// @returns this or 0 or mid. if returns this or 0 out_* are not filled
 		Body trim(Trim_kind kind=TRIM_BOTH, const char* chars=0,
-			size_t* out_start=0, size_t* out_length=0) const;
+			size_t* out_start=0, size_t* out_length=0, Charset* source_charset=0) const;
 	};
 
 	struct C {
@@ -386,8 +486,24 @@ public:
 
 	static const String Empty;
 
-	explicit String(const char* cstr=0, size_t helper_length=0, bool tainted=false);
-	explicit String(const C cstr, bool tainted=false);
+	explicit String(){};
+	explicit String(const char* cstr, Language alang=L_CLEAN){
+		if(cstr && *cstr){
+			body=cstr;
+			langs=alang;
+		}
+	}
+	explicit String(const char* cstr, Language alang, size_t alength){
+		if(cstr && *cstr){
+			body=cstr;
+#ifdef STRING_LENGTH_CACHING
+			body.set_length(alength);
+#endif
+			langs=alang;
+		}
+	}
+
+	String(int value, char *format);
 	String(Body abody, Language alang): body(abody), langs(alang) {
 		ASSERT_STRING_INVARIANT(*this);
 	}
@@ -396,29 +512,48 @@ public:
 	}
 
 	/// for convinient hash lookup
+#ifdef HASH_CODE_CACHING
+	operator const Body&() const { return body; }
+#else
 	operator const Body() const { return body; }
+#endif
 
 	bool is_empty() const { return body.is_empty(); }
 	size_t length() const { return body.length(); }
 	size_t length(Charset& charset) const;
 
-	/// convert to CORD. if 'lang' known, forcing 'lang' to it
-	Body cstr_to_string_body(Language lang=L_AS_IS, 
-		SQL_Connection* connection=0,
-		const Request_charsets *charsets=0) const;
+	/// convert to CORD forcing lang tainting
+	Body cstr_to_string_body_taint(Language lang, SQL_Connection* connection=0, const Request_charsets *charsets=0) const;
+	/// convert to CORD with tainting dirty to lang
+	Body cstr_to_string_body_untaint(Language lang, SQL_Connection* connection=0, const Request_charsets *charsets=0) const;
 
-	/// convert to constant C string. if 'lang' known, forcing 'lang' to it
-	const char* cstr(Language lang=L_AS_IS, 
-		SQL_Connection* connection=0,
-		const Request_charsets *charsets=0) const {
-		return cstr_to_string_body(lang, connection, charsets).cstr();
+	/// 
+	const char* cstr() const {
+		return body.cstr();
 	}
-	/// convert to Modifiable C string. if 'lang' known, forcing 'lang' to it
-	char *cstrm(Language lang=L_AS_IS, 
-		SQL_Connection* connection=0,
-		const Request_charsets *charsets=0) const {
-		return cstr_to_string_body(lang, connection, charsets).cstrm();
+	/// 
+	char* cstrm() const {
+		return body.cstrm();
 	}
+
+	/// convert to constant C string forcing lang tainting
+	const char* taint_cstr(Language lang, SQL_Connection* connection=0, const Request_charsets *charsets=0) const {
+		return cstr_to_string_body_taint(lang, connection, charsets).cstr();
+	}
+	char *taint_cstrm(Language lang, SQL_Connection* connection=0, const Request_charsets *charsets=0) const {
+		return cstr_to_string_body_taint(lang, connection, charsets).cstrm();
+	}
+
+	/// convert to constant C string with tainting dirty to lang
+	const char* untaint_cstr(Language lang, SQL_Connection* connection=0, const Request_charsets *charsets=0) const {
+		return cstr_to_string_body_untaint(lang, connection, charsets).cstr();
+	}
+	char *untaint_cstrm(Language lang, SQL_Connection* connection=0, const Request_charsets *charsets=0) const {
+		return cstr_to_string_body_untaint(lang, connection, charsets).cstrm();
+	}
+
+	const char* untaint_and_transcode_cstr(Language lang, const Request_charsets *charsets) const;
+
 	/// puts pieces to buf
 	Cm serialize(size_t prolog_size) const;
 	/// appends pieces from buf to self
@@ -441,13 +576,17 @@ public:
 		return Body(x).ncmp(0/*x_begin*/, body, 0/*y_begin*/, length())==0;
 	}
 
-	String& append_to(String& dest, Language lang, bool forced) const;
+	String& append_to(String& dest, Language lang, bool forced=false) const;
 	String& append(const String& src, Language lang, bool forced=false) { 
 		return src.append_to(*this, lang, forced);
 	}
 	String& operator << (const String& src) { return append(src, L_PASS_APPENDED); }
 	String& operator << (const char* src) { return append_help_length(src, 0, L_AS_IS); }
-	String& operator << (const Body src);
+	String& operator << (const Body& src){
+		langs.appendHelper(body, L_AS_IS, src);
+		body<<src;
+		return *this;
+	}
 
 	/// extracts first char of a string, if any
 	char first_char() const {
@@ -503,9 +642,7 @@ public:
 			prematch/match/postmatch/1/2/3/...
 		@endverbatim
 	*/
-	Table* match(Charset& source_charset,
-		const String& regexp, 
-		const String* options,
+	Table* match(VRegex* vregex,
 		Row_action row_action, void *info,
 		int& matches_count) const;
 	enum Change_case_kind {
@@ -515,7 +652,7 @@ public:
 	String& change_case(Charset& source_charset,
 		Change_case_kind kind) const;
 	const String& replace(const Dictionary& dict) const;
-	const String& trim(Trim_kind kind=TRIM_BOTH, const char* chars=0) const;
+	const String& trim(Trim_kind kind=TRIM_BOTH, const char* chars=0, Charset* source_charset=0) const;
 	double as_double() const { return pa_atod(cstr(), this); }
 	int as_int() const { return pa_atoi(cstr(), this); }
 	bool as_bool() const { return as_int()!=0; }
@@ -527,23 +664,12 @@ private: //disabled
 
 };
 
-template<>
-inline size_t get_length<String::Body>(String::Body body) {
-	return body.length();
-}
-
+#ifndef HASH_CODE_CACHING
 /// simple hash code of string. used by Hash
 inline uint hash_code(const String::Body self) {
-	return self.hash_code();
-}
-
-
-/// now that we've declared specialization we can use it
-inline String& String::operator << (const String::Body src) { 
-	langs.append(body, L_AS_IS, src.length());
-	body<<src;
-	return *this;
+	return self.get_hash_code();
 }
+#endif
 
 
 #endif
