@@ -1,7 +1,7 @@
 /** @file
 	Parser: plugins to xml library, controlling i/o.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
@@ -11,14 +11,14 @@
 #ifndef PA_XML_IO_H
 #define PA_XML_IO_H
 
-static const char * const IDENT_XML_IO_H="$Date: 2005-08-09 08:14:50 $";
+static const char * const IDENT_XML_IO_H="$Date: 2009-05-14 11:27:23 $";
 
 #include "pa_string.h"
 #include "pa_hash.h"
 
 void pa_xml_io_init();
 
-typedef Hash<const String::Body, bool> HashStringBool;
+typedef HashString<bool> HashStringBool;
 
 void pa_xmlStartMonitoringDependencies();
 HashStringBool* pa_xmlGetDependencies();
