@@ -1,16 +1,16 @@
 /** @file
 	Parser: Value, Method, Junction .
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VALUE_H
 #define PA_VALUE_H
 
-static const char * const IDENT_VALUE_H="$Date: 2007-04-23 10:30:49 $";
+static const char * const IDENT_VALUE_H="$Date: 2009-09-18 09:16:07 $";
 
-#include "pa_string.h"
+#include "pa_common.h"
 #include "pa_array.h"
 #include "pa_exception.h"
 #include "pa_property.h"
@@ -19,20 +19,18 @@ static const char * const IDENT_VALUE_H="$Date: 2007-04-23 10:30:49 $";
 
 class VStateless_class;
 class WContext;
-class Request; class Request_charsets;
+class Request;
+class Request_charsets;
 class Junction;
 class VJunction;
 class Method;
-template<typename K, typename V> class Hash;
 class Value;
-typedef Hash<const String::Body, Value*> HashStringValue; 
-typedef Hash<const String::Body, PA_Object*> HashStringObject;
-typedef Array<Value*> ArrayValue;
 class MethodParams;
 class VObject;
 class VMethodFrame;
 class VFile;
 class Table;
+typedef Array<Value*> ArrayValue;
 
 ///	grandfather of all @a values in @b Parser
 class Value: public PA_Object {
@@ -41,20 +39,15 @@ public: // Value
 	/// value type, used for error reporting and 'is' expression operator
 	virtual const char* type() const =0;
 
-	/** remember derived class instance 
-	    - VObject: the only client
-	*/
-	virtual VObject* set_derived(VObject* /*aderived*/);
-
 	/**
 		all except VObject/VClass: this if @atype eq type()
 		VObject/VClass: can locate parent class by it's type
 	*/
-	virtual Value* as(const char* atype, bool /*looking_up*/) {
+	virtual Value* as(const char* atype) {
 		return atype && strcmp(type(), atype)==0?this:0;
 	}
 	/// type checking helper, uses Value::as
-	bool is(const char* atype) { return as(atype, false)!=0; }
+	bool is(const char* atype) { return as(atype)!=0; }
 	
 	/// is this value defined?
 	virtual bool is_defined() const { return true; }
@@ -85,6 +78,8 @@ public: // Value
 	
 	/// extract const String
 	virtual const String* get_string() { return 0; }
+
+	virtual HashStringValue* get_fields() { return 0; }
 	
 	/// extract double
 	virtual double as_double() const { bark("is '%s', it does not have numerical (double) value"); return 0; }
@@ -96,30 +91,21 @@ public: // Value
 	virtual bool as_bool() const { bark("is '%s', it does not have logical value"); return 0; }
 	
 	/// extract file
-	virtual VFile* as_vfile(String::Language lang=String::L_UNSPECIFIED, 
-		const Request_charsets* charsets=0);
+	virtual VFile* as_vfile(String::Language lang, const Request_charsets* charsets=0);
 	
 	/// extract Junction
 	virtual Junction* get_junction();
 	
-	/// extract Property
-	virtual Property* get_property() { return 0; }
-	
-	/** extract base object of Value
-		@return for
-		- VObject: fbase
-	*/
-	virtual Value* base_object();
-	
 	/// @return Value element; can return Junction for methods; Code-Junction for code; Getter-Junction for property
-	virtual Value* get_element(const String& /*aname*/, Value& /*aself*/, bool /*looking_up*/);
+	virtual Value* get_element(const String& /*aname*/);
 
 	/// indicator value meaning that put_element overwritten something
 	#define PUT_ELEMENT_REPLACED_ELEMENT reinterpret_cast<const VJunction*>(1)
+
 	/// store Value element under @a name
 	/// @returns putter method junction, or it can just report[PUT_ELEMENT_REPLACED_ELEMENT] 
 	/// that it replaced something in base fields 
-	virtual const VJunction* put_element(Value& /*aself*/, const String& aname, Value* /*avalue*/, bool /*areplace*/) { 
+	virtual const VJunction* put_element(const String& aname, Value* /*avalue*/, bool /*areplace*/) { 
 		// to prevent modification of system classes,
 		// created at system startup, and not having exception
 		// handler installed, we neet to bark using request.pool
@@ -128,14 +114,10 @@ public: // Value
 	}
 	
 	/// extract VStateless_class
-	virtual VStateless_class *get_class()=0;
+	virtual VStateless_class* get_class()=0;
 
-	/// extract VStateless_class
-	virtual VStateless_class *get_last_derived_class() {
-		return get_class();
-	};
-	/// extract base object or class of Value, if any
-	virtual Value* base() { return 0; }
+	/// extract base class, if any
+	virtual VStateless_class* base() { return 0; }
 
 	/// extract VTable
 	virtual Table* get_table() { return 0; }
@@ -169,7 +151,7 @@ protected:
 /**
 	$content-type[text/html] -> 
 		content-type: text/html
-	$content-type[$value[text/html] charset[windows-1251]] -> 
+	$content-type[$.value[text/html] $.charset[windows-1251]] -> 
 		content-type: text/html; charset=windows-1251
 */
 const String& attributed_meaning_to_string(Value& meaning, 
