@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b cookie class decls.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VCOOKIE_H
 #define PA_VCOOKIE_H
 
-static const char * const IDENT_VCOOKIE_H="$Date: 2008-07-15 12:54:24 $";
+static const char * const IDENT_VCOOKIE_H="$Date: 2009-08-08 13:30:21 $";
 
 #include "pa_hash.h"
 #include "pa_common.h"
@@ -16,6 +16,7 @@ static const char * const IDENT_VCOOKIE_H="$Date: 2008-07-15 12:54:24 $";
 #include "pa_sapi.h"
 
 #define COOKIE_CLASS_NAME "cookie"
+static const String cookie_class_name(COOKIE_CLASS_NAME);
 
 // forwards
 class Request_info;
@@ -34,10 +35,10 @@ public: // Value
 	/// VCookie: 0
 	override VStateless_class *get_class() { return 0; }
 
-	// cookie: CLASS,method,field
-	override Value* get_element(const String& aname, Value& aself, bool /*looking_up*/);
+	// cookie: CLASS, CLASS_NAME, field
+	override Value* get_element(const String& aname);
 	// cookie: field
-	override const VJunction* put_element(Value& self, const String& name, Value* value, bool replace);
+	override const VJunction* put_element(const String& name, Value* value, bool replace);
 
 public: // usage
 
