@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b env class decl.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VENV_H
 #define PA_VENV_H
 
-static const char * const IDENT_VENV_H="$Date: 2007-09-17 15:13:45 $";
+static const char * const IDENT_VENV_H="$Date: 2009-08-08 13:30:21 $";
 
 // includes
 
@@ -19,6 +19,7 @@ static const char * const IDENT_VENV_H="$Date: 2007-09-17 15:13:45 $";
 // defines
 
 #define ENV_CLASS_NAME "env"
+static const String env_class_name(ENV_CLASS_NAME);
 
 /// env class
 class VEnv: public Value {
@@ -29,8 +30,8 @@ public: // Value
 	/// VEnv: 0
 	VStateless_class *get_class() { return 0; }
 
-	// VEnv: field
-	Value* get_element(const String& aname, Value& /*aself*/, bool /*looking_up*/);
+	// env: CLASS, CLASS_NAME, field
+	Value* get_element(const String& aname);
 
 public: // usage
 
