@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b mail class decls.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VMAIL_H
 #define PA_VMAIL_H
 
-static const char * const IDENT_VMAIL_H="$Date: 2005-08-09 08:14:55 $";
+static const char * const IDENT_VMAIL_H="$Date: 2009-09-27 22:10:02 $";
 
 #include "classes.h"
 #include "pa_common.h"
@@ -18,6 +18,7 @@ static const char * const IDENT_VMAIL_H="$Date: 2005-08-09 08:14:55 $";
 
 #define MAIL_RECEIVED_ELEMENT_NAME "received"
 #define MAIL_OPTIONS_NAME "options"
+#define MAIL_DEBUG_NAME "print-debug"
 
 // forwards
 
@@ -35,7 +36,7 @@ public: // Value
 	override const char* type() const { return "mail"; }
 	
 	// mail: CLASS,methods,received field
-	Value* get_element(const String& aname, Value& aself, bool /*looking_up*/);
+	Value* get_element(const String& aname);
 
 public: // usage
 
