@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b memory parser class.
 
-	Copyright (c) 2001-2005 ArtLebedev Group (http://www.artlebedev.com)
+	Copyright (c) 2001-2009 ArtLebedev Group (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VMEMORY_H
 #define PA_VMEMORY_H
 
-static const char * const IDENT_VMEMORY_H="$Date: 2005-08-09 08:14:55 $";
+static const char * const IDENT_VMEMORY_H="$Date: 2009-08-08 13:30:21 $";
 
 #include "classes.h"
 #include "pa_vstateless_object.h"
@@ -23,9 +23,9 @@ public: // Value
 	const char* type() const { return "memory"; }
 
 	/// memory: CLASS,method
-	Value* get_element(const String& aname, Value& aself, bool looking_up) {
+	Value* get_element(const String& aname) {
 		// $CLASS,$method
-		if(Value* result=VStateless_class::get_element(aname, aself, looking_up))
+		if(Value* result=VStateless_class::get_element(aname))
 			return result;
 
 		return 0;
